@@ -374,6 +374,8 @@ class BinaryOp:
         elif ret_op == 'endswith':
             ret_op = 'like'
             rhv = f"CONCAT('%', {rhv})"
+        elif 'is not' in ret_op and rhv == 'null':
+            rhv = 'null'
 
         return f'({lhv} {ret_op.replace("==", "=")} {rhv})', params, counter
 
@@ -397,9 +399,11 @@ class BinaryOp:
             v = f':{var}'
         elif isinstance(v, (Attr, AttributeString)) and prefix is not None:
             if isinstance(v, Attr):
-                v.attr._value = f'{prefix}."{v.attr._value}"'
+                if not v.attr._value.startswith(f'{prefix}."'):
+                    v.attr._value = f'{prefix}."{v.attr._value}"'
             else:
-                v._value = f'{prefix}."{v._value}"'
+                if not v._value.startswith(f'{prefix}."'):
+                    v._value = f'{prefix}."{v._value}"'
 
         return v, params, counter
 
